"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCached = void 0;
var _lodash = require("lodash");
var _react = require("react");
/**
 * Saves only not empty, not undefined and not null values
 * @param value any value to save
 * @returns the previous saved non-empty value
 */
const useCached = value => {
  const ref = (0, _react.useRef)();
  (0, _react.useEffect)(() => {
    // Save only value, not empty / undefined / null
    // Check all of these cases, because we may have `false` value to work with
    if (!((0, _lodash.isEmpty)(value) || (0, _lodash.isUndefined)(value) || (0, _lodash.isNull)(value))) {
      ref.current = value;
    }
  }, [value]);
  return ref.current;
};
exports.useCached = useCached;
//# sourceMappingURL=useCached.js.map