"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDeepCompareEffect = void 0;
var _lodash = require("lodash");
var _react = require("react");
/**
 * Allows a component to run an effect only when the dependencies have changed using a deep comparison instead of a shallow comparison
 * @param callback function that must be called when the deps change
 * @param dependencies deep comparison dependencies that will be used to trigger the callback
 */
const useDeepCompareEffect = (callback, dependencies) => {
  const currentDependenciesRef = (0, _react.useRef)(null);
  if (!(0, _lodash.isEqual)(currentDependenciesRef.current, dependencies)) {
    currentDependenciesRef.current = dependencies;
  }

  // eslint-disable-next-line react-hooks/exhaustive-deps
  (0, _react.useEffect)(callback, [currentDependenciesRef.current]);
};
exports.useDeepCompareEffect = useDeepCompareEffect;
//# sourceMappingURL=useDeepCompareEffect.js.map