"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.usePrevious = void 0;
var _react = require("react");
/**
 * Saves the previous state of the value
 * @param value the current value from the useState (usually) to save its prev value
 * @param valuesToIgnore an array of values to ignore when saving the previous value
 * @returns the previous saved value
 */
const usePrevious = function (value) {
  let valuesToIgnore = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  const ref = (0, _react.useRef)();
  (0, _react.useEffect)(() => {
    if (valuesToIgnore.includes(value)) return;
    ref.current = value;
  }, [value, valuesToIgnore]);
  return ref.current;
};
exports.usePrevious = usePrevious;
//# sourceMappingURL=usePrevious.js.map