"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useStateWithCached = void 0;
var _react = require("react");
var _useCached = require("./useCached");
/**
 * Extends React.useState with a cached non-empty state as a third output value of array
 * @param initialValue initial value as the third value of the state and prevState
 * @returns [state, setState, cachedState] - cachedState is the non-empty state, state is the current state (including undefined and null), setState is the setter for the state
 */
const useStateWithCached = initialValue => {
  const [state, setState] = (0, _react.useState)(initialValue);
  const cachedState = (0, _useCached.useCached)(state);
  return [state, setState, cachedState];
};
exports.useStateWithCached = useStateWithCached;
//# sourceMappingURL=useStateWithCached.js.map