"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useToggle = void 0;
var _react = require("react");
/**
 * Extended useState for boolean value with exported toggle function
 * @param defaultValue boolean value to set as default
 * @returns [isValue, toggleValue] - isValue is the current boolean value, toggleValue is the toggle setter for the boolean value without any params
 */
const useToggle = defaultValue => {
  const [isValue, setIsValue] = (0, _react.useState)(defaultValue);
  const toggleValue = (0, _react.useCallback)(() => setIsValue(prevState => !prevState), []);
  return [isValue, toggleValue];
};
exports.useToggle = useToggle;
//# sourceMappingURL=useToggle.js.map