"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useUpdateEffect = void 0;
var _react = require("react");
/**
 * Extended useEffect - skip first function call on mount and leave only update calls
 * @param callback function that must be called when the deps change and skip first time as main purpose
 * @param deps dependencies that will be used to trigger the callback
 */
const useUpdateEffect = (callback, deps) => {
  const firstRenderRef = (0, _react.useRef)(true);
  (0, _react.useEffect)(() => {
    if (firstRenderRef.current) {
      firstRenderRef.current = false;
      return;
    }

    // eslint-disable-next-line consistent-return
    return callback();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, deps);
};
exports.useUpdateEffect = useUpdateEffect;
//# sourceMappingURL=useUpdateEffect.js.map