import { isEqual } from 'lodash';
import { useEffect, useRef } from 'react';
/**
 * Allows a component to run an effect only when the dependencies have changed using a deep comparison instead of a shallow comparison
 * @param callback function that must be called when the deps change
 * @param dependencies deep comparison dependencies that will be used to trigger the callback
 */
export const useDeepCompareEffect = (callback, dependencies) => {
  const currentDependenciesRef = useRef(null);
  if (!isEqual(currentDependenciesRef.current, dependencies)) {
    currentDependenciesRef.current = dependencies;
  }

  // eslint-disable-next-line react-hooks/exhaustive-deps
  useEffect(callback, [currentDependenciesRef.current]);
};
//# sourceMappingURL=useDeepCompareEffect.js.map